import { __decorate } from "tslib";
import { customElement } from '@microsoft/fast-element';
import { BaseDatasource, logger } from '../utils';
let DataGridDatasource = class DataGridDatasource extends BaseDatasource {
    constructor() {
        super(...arguments);
        this.isSnapshot = true;
    }
    async connectedCallback() {
        super.connectedCallback();
        this.dataGrid = this.parentElement;
        if (this.dataGrid && this.resourceName && this.connect.isConnected) {
            this.fetchGenesisData();
        }
    }
    getColumnDefs(fieldsMetadata) {
        const colDefsFromGenesisData = fieldsMetadata?.flatMap((field) => {
            if (this.fields && !this.fields.includes(field.name)) {
                return [];
            }
            return { columnDataKey: field.name };
        });
        return colDefsFromGenesisData;
    }
    clearData() {
        logger.debug('clearData - Method not implemented.');
    }
    syncComponentData(snapshotData) {
        const rowData = snapshotData ?? Array.from(this.rowsSyncedWithStream.values());
        const columns = this.getColumnDefs(this.datasource.fieldMetadata);
        this.dataGrid.columnDefinitions = columns;
        this.dataGrid.rowsData = rowData;
    }
    handleStreamInserts(insertedRows) {
        logger.debug('handleStreamInserts - Method not implemented.');
    }
    handleStreamDeletes(deletedRows) {
        logger.debug('handleStreamDeletes - Method not implemented.');
    }
    handleStreamUpdates(updatedRows) {
        logger.debug('handleStreamUpdates - Method not implemented.');
    }
};
DataGridDatasource = __decorate([
    customElement({
        name: 'data-grid-datasource',
    })
], DataGridDatasource);
export { DataGridDatasource };
