import { __decorate } from "tslib";
import { observable } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { logger } from '../utils';
import { foundationErrorDialogStyles as styles } from './error-dialog.styles';
import { errorDialogTemplate as template } from './error-dialog.template';
export const foundationErrorDialogShadowOptions = {
    mode: 'open',
    delegatesFocus: true,
};
/**
 * @tagname %%prefix%%-error-dialog
 */
export class ErrorDialog extends FoundationElement {
    connectedCallback() {
        super.connectedCallback();
    }
    /**
     * Show the Error Dialog.
     */
    show() {
        this.dialog.show();
    }
    /**
     * Dismiss the Error Dialog from display and calls the dismissing action.
     */
    dismiss() {
        if (this.error?.config?.dialog?.dismissingAction?.action) {
            this.error.config.dialog.dismissingAction.action();
        }
        this.closeDialog();
    }
    /**
     * Dismiss the Error Dialog from display.
     */
    closeDialog() {
        try {
            this.dialog.close();
            this.remove();
        }
        catch (e) {
            logger.error(e);
        }
    }
}
__decorate([
    observable
], ErrorDialog.prototype, "error", void 0);
/**
 * The Foundation Error Dialog
 *
 * @public
 * @remarks
 * HTML Element: <foundation-error-dialog>
 */
export const foundationErrorDialog = ErrorDialog.compose({
    baseName: 'error-dialog',
    template,
    styles,
    shadowOptions: foundationErrorDialogShadowOptions,
});
