import { __decorate } from "tslib";
import { attr, customElement } from '@microsoft/fast-element';
import { BaseDatasource, logger } from '../utils';
let MultiselectDatasource = class MultiselectDatasource extends BaseDatasource {
    constructor() {
        super(...arguments);
        this.isSnapshot = true;
    }
    async connectedCallback() {
        super.connectedCallback();
        this.fields = this.labelField ? this.valueField?.concat(' ', this.labelField) : this.valueField;
        this.select = this.parentElement;
        if (this.select &&
            this.valueField &&
            ((this.resourceName && this.connect.isConnected) || this.data)) {
            this.fetchGenesisData();
        }
        if (!this.valueField) {
            logger.warn('Specify field for values in options (e.g value-field="VALUE") and optionally field for label which is supported only in select and combobox (e.g label-field="NAME")');
        }
    }
    clearData() {
        this.select.options = [];
    }
    syncComponentData(snapshotData) {
        const rowData = snapshotData ?? Array.from(this.rowsSyncedWithStream.values());
        const options = rowData.map((row) => ({
            value: row[this.valueField],
            label: row[this.labelField],
        }));
        this.select.options = options;
    }
    handleStreamInserts(insertedRows) {
        logger.debug('handleStreamInserts - Method not implemented.');
    }
    handleStreamDeletes(deletedRows) {
        logger.debug('handleStreamDeletes - Method not implemented.');
    }
    handleStreamUpdates(updatedRows) {
        logger.debug('handleStreamUpdates - Method not implemented.');
    }
};
__decorate([
    attr({ attribute: 'value-field' })
], MultiselectDatasource.prototype, "valueField", void 0);
__decorate([
    attr({ attribute: 'label-field' })
], MultiselectDatasource.prototype, "labelField", void 0);
MultiselectDatasource = __decorate([
    customElement({
        name: 'multiselect-datasource',
    })
], MultiselectDatasource);
export { MultiselectDatasource };
