var OptionsDatasource_1;
import { __decorate } from "tslib";
import { attr, customElement, DOM, observable } from '@microsoft/fast-element';
import { BaseDatasource, logger } from '../utils';
let OptionsDatasource = OptionsDatasource_1 = class OptionsDatasource extends BaseDatasource {
    constructor() {
        super(...arguments);
        this.optionElement = 'fast-option';
        this.isSnapshot = true;
    }
    async connectedCallback() {
        super.connectedCallback();
        this.fields = this.labelField ? this.valueField?.concat(' ', this.labelField) : this.valueField;
        this.select = this.parentElement;
        this.select.addEventListener('change', (e) => {
            const selectedOption = this.options.find((option) => option.label === e.target.value);
            this.select.$emit('value-change', selectedOption);
        });
        if (this.select &&
            this.valueField &&
            ((this.resourceName && this.connect.isConnected) || this.data)) {
            this.fetchGenesisData();
        }
        if (!this.valueField) {
            logger.warn('Specify field for values in options (e.g value-field="VALUE") and optionally field for label (e.g label-field="NAME")');
        }
    }
    clearData() {
        Array.from(this.select.children).forEach((x) => {
            if (!(x instanceof OptionsDatasource_1)) {
                this.select.removeChild(x);
            }
        });
        this.select.value = '';
        this.select.initialValue = '';
    }
    syncComponentData(snapshotData) {
        const rowData = snapshotData ?? Array.from(this.rowsSyncedWithStream.values());
        this.options = rowData.map((row) => ({
            value: row[this.valueField],
            label: this.labelFormatter ? this.labelFormatter(row[this.labelField]) : row[this.labelField],
        }));
        const listboxOptions = this.options.map(({ value, label }) => {
            const option = document.createElement(this.optionElement);
            option.textContent = label ? label : value;
            option.value = value;
            return option;
        });
        listboxOptions.forEach((x) => {
            this.select.appendChild(x);
        });
        const initialLabel = this.initialSelectedValue || this.initialSelectedValue === 0
            ? this.options.find((x) => x.value === this.initialSelectedValue)?.label
            : '';
        DOM.queueUpdate(() => {
            this.select.value = initialLabel;
        });
    }
    handleStreamInserts(insertedRows) {
        logger.debug('handleStreamInserts - Method not implemented.');
    }
    handleStreamDeletes(deletedRows) {
        logger.debug('handleStreamDeletes - Method not implemented.');
    }
    handleStreamUpdates(updatedRows) {
        logger.debug('handleStreamUpdates - Method not implemented.');
    }
};
__decorate([
    attr({ attribute: 'label-field' })
], OptionsDatasource.prototype, "labelField", void 0);
__decorate([
    attr({ attribute: 'value-field' })
], OptionsDatasource.prototype, "valueField", void 0);
__decorate([
    observable
], OptionsDatasource.prototype, "labelFormatter", void 0);
OptionsDatasource = OptionsDatasource_1 = __decorate([
    customElement({
        name: 'options-datasource',
    })
], OptionsDatasource);
export { OptionsDatasource };
